@section('title', 'VisiMisi')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Visi Misi {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    “Menjadi Universitas unggul dalam melahirkan lulusan yang kompeten dalam bidang kesehatan, sosial, dan ekonomi bisnis sehingga mampu bersaing dalam level nasional tahun 2040”
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                        Menyiapkan peserta didik agar menjadi lulusan yang berintelektual tinggi, berbudi pekerti luhur serta berjiwa enterpreneur
                    </li>
                    <li>
                        Melaksanakan karya ilmiah di bidang teknik, kesehatan dan ekonomi bisnis dan terlibat aktif dalam penelitian ilmiah yang dapat digunakan dalam rangka pengembangan ilmu pengetahuan, teknologi untuk meningkatkan mutu dan jangkauan pelayanan kesehatan
                    </li>
                    <li>
                        Meningkatkan derajat kesehatan masyarakat dengan memberikan pelayanan terbaik sebagai bentuk pengabdian masyarakat dalam pembangunan bangsa dan sistem pendidikan yang sesuai dengan perkembangan IPTEK sebagai bentuk kepedulian institusis
                    </li>
                    <li>
                        Meningkatkan jejaring nasional dan global dengan melakukan kerjasama dengan institusi terkait dalam maupun luar negeri
                    </li>
                    <li>
                        Menciptakan iklim akademik yang mampu mendukung perwujudan visi Universitas Yarsi Pratama
                    </li>
                </ul>
            </div>
            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}
                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
