<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STMIK Borneo Internasional menawarkan program S1 Sistem Informasi yang dirancang untuk mencetak lulusan unggul di bidang teknologi informasi, analisis data, dan manajemen sistem. Dengan kurikulum berbasis industri, fasilitas modern, serta bimbingan dari dosen berpengalaman, mahasiswa akan mendapatkan keterampilan praktis dan teoritis yang siap diterapkan di dunia kerja. Program ini membuka peluang karier sebagai analis sistem, pengembang perangkat lunak, manajer IT, hingga data scientist. Bergabunglah dengan STMIK Borneo Internasional dan raih masa depan cemerlang di era digital.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STMIK Borneo Internasional, kampus STMIK Borneo Internasional , biaya kuliah kampus STMIK BI , biaya kuliah, kelas sabtu, akreditasi STMIK BI, kelas karyawan terjangkau Balikpapan , S1 Sistem Informasi, kampus murah Di Balikpapan , kampus Di Balikpapan , STMIK BI, biaya kuliah, kelas sabtu, akreditasi STMIK Borneo Internasional ,
     Kampus Kelas Karyawan Di Balikpapan , Kuliah Sambil Kerja Di Balikpapan , Universitas Terbaik di Balikpapan  untuk Karyawan, Biaya Kuliah Terjangkau di Balikpapan , Universitas Kelas Sabtu Minggu Di Balikpapan , Akreditasi Universitas Di Balikpapan ,Perguruan Tinggi Swasta Murah di Balikpapan , Program S1 Sistem Informasi ,  Kampus Swasta Terbaik Balikpapan , Universitas Murah  Di Balikpapan  terakreditasi Baik,
     Kampus Terjangkau di Balikpapan  untuk Karyawan, , Kuliah dengan Biaya Termurah bulan di Balikpapan  , Universitas dengan Kelas Online Balikpapan , Kampus Swasta Kelas Sabtu Minggu di Balikpapan , Biaya Kuliah  Diploma Murah di Balikpapan , Biaya Kuliah  S1 Murah di Balikpapan  , Kampus dengan Program Studi Lengkap di Balikpapan " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <!--ADS GSC-->
        <meta name="google-site-verification" content="Vask-N4lg7mjZcGkwZOhi-AgMXfMrnRj98jWuBA3twc" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; STMIK Borneo Internasional (Kelas Karyawan)</title>
    <meta property="og:title" content="STMIK Borneo Internasional (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="STMIK Borneo Internasional (Kelas Karyawan)">
    <meta property="og:image" content="stmik-borneo.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STMIK Borneo Internasional menawarkan program S1 Sistem Informasi yang dirancang untuk membekali mahasiswa dengan keahlian dalam teknologi informasi, analisis data, dan manajemen sistem. Dengan kurikulum berbasis industri dan dosen berpengalaman, lulusan siap menghadapi tantangan di dunia digital serta berkarier sebagai analis sistem, pengembang perangkat lunak, atau profesional IT lainnya. Bergabunglah dan wujudkan masa depan digital Anda bersama STMIK Borneo Internasional.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STMIK Borneo Internasional (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan S1 Sistem Informasi di STMIK Borneo Internasional dirancang untuk profesional yang ingin meningkatkan keterampilan di bidang teknologi informasi tanpa mengganggu pekerjaan. Dengan jadwal fleksibel, kurikulum berbasis industri, dan dukungan dosen berpengalaman, mahasiswa dapat menguasai analisis data, pengelolaan sistem, serta pengembangan perangkat lunak. Dapatkan gelar S1 sambil tetap bekerja dan tingkatkan peluang karier Anda di dunia digital bersama STMIK Borneo Internasional!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content="stmik-borneo.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STMIK Borneo Internasional | Kuliah Karyawan (K2)" />

    
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Hitam-Oranye/resources/views/auth/app.blade.php ENDPATH**/ ?>