<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('{{ asset('./images/background/bg-sambutan.png') }}');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="{{ asset('./images/sambutan/sambutan.png') }}" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="{{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <x-header-section subtext=" SAMBUTAN Rektor {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" subtext-color="#fff" title=""
            title-color="#fff" />
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
            Selamat datang di Universitas Yarsi Pratama (UYP), tYarsi Pratama University adalah Perguruan Tinggi Swasta Yaitu Yayasan Husada Madani di kota Tangerang  yang berdiri tahun 2001 dengan menyelenggarakan Pendidikan Akademik Kebidanan Serta Akademi Teknik Radiodiagnosik dan Radioterapi Widya Dharma, kemudian digabungkan menjadi Yarsi Pratama University dengan nomor perijinan SK Kemendikbud RI nomor: 889/E/O/2023, terdiri dari 7 (tujuh) program studi yang sangat dibutuhkan oleh masyarakat, dunia industri serta dunia kesehatan</p>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
            Angka Partisipasi Kasar Provinsi Banten pada Tahun 2023 yang masih rendah dibandingkan dengan Provinsi DKI Jakarta dan Bali, menjadikan Universitas Yarsi Pratama menjadi salah satu Perguruan Tinggi dengan biaya mterjangkau di Kab. tangerang. hal ini dilakukan untuk memfasilitasi seluruh masyarakat Kab. Tangerang pada khususnya dan seluruh masyarakat provinsi Banten pada umumnya.</p>
        <x-button url="/sejarah-singkat">BACA SELENGKAPNYA</x-button>
    </div>
</div>
