<?php $__env->startSection('title', 'VisiMisi'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Visi Misi '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Visi Misi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Menjadi perguruan tinggi unggulan di bidang manajemen dan informatika
                    yang inovatif, adaptif, dan berdaya saing global dalam pengembangan
                    teknologi digital serta kewirausahaan berbasis teknologi.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                <li>
                    Pendidikan Berkualitas
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Menyelenggarakan pendidikan di bidang manajemen dan informatika berbasis teknologi digital yang unggul, kreatif, dan sesuai dengan perkembangan industri 4.0 dan 5.0.
                </p>
                <li>
                    Riset dan Inovasi
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Mengembangkan riset dan inovasi berbasis teknologi informasi untuk memberikan solusi nyata bagi masyarakat, industri, dan pemerintahan.
                </p>
                <li>
                    Kewirausahaan Digital
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Mendorong budaya kewirausahaan berbasis teknologi dengan mencetak lulusan yang mampu menciptakan startup dan bisnis digital yang berdaya saing.
                </p>                
                <li>
                    Kolaborasi dan Kemitraan
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Memperkuat jaringan kerjasama dengan dunia industri, institusi pendidikan,dan komunitas teknologi baik nasional maupun internasional.
                </p>                
                <li>
                    Pengabdian kepada Masyarakat 
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Mengaplikasikan keilmuan di bidang manajemen dan informatika melalui program pengabdian kepada masyarakat guna meningkatkan kesejahteraan dan literasi digital.
                </p>                <li>
                    Transformasi Digital Kampus
                </li>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Mewujudkan kampus berbasis teknologi dengan sistem pembelajaran modern,digitalisasi layanan akademik, serta pengelolaan data yang efisien dan transparan.
                </p>
                
               
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>

                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?></p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Biru-Oranye/resources/views/Frontend/visimisi.blade.php ENDPATH**/ ?>