<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
                STMIK Borneo Internasional didirikan pada 7 April 2009 berdasarkan SK 38DO2009 dengan komitmen untuk mencetak generasi unggul di bidang teknologi informasi. Kampus ini menawarkan pendidikan berkualitas dengan tenaga pengajar profesional, fasilitas yang memadai, serta program studi seperti Sistem Informasi dan Manajemen Informatika, dan bertujuan untuk mengembangkan potensi mahasiswa agar dapat berkontribusi pada masyarakat di era digital ini. <br>
<br>
Detail Penting:<br>
Tanggal Pendirian: 7 April 2009. <br>
Dasar Hukum: Nomor SK 38DO2009. <br>
Visi: Mencetak generasi unggul di bidang teknologi informasi yang mampu bersaing di tingkat nasional dan global. <br>
Program Studi: Sistem Informasi dan Manajemen Informatika. <br>
Dosen dan Mahasiswa: Memiliki tenaga pengajar profesional dan infrastruktur yang mendukung proses belajar mengajar. <br>
Fokus Pendidikan: Selain ilmu pengetahuan, STMIK Borneo juga fokus pada pembentukan karakter, pengembangan jaringan, kreativitas, dan kepemimpinan.
            </p>

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Biru-Oranye/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>