@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="first-line:pl-5">

                Angka Partisipasi Kasar Provinsi Banten pada Tahun 2023 yang masih rendah di bandingkan dengan Provinsi DKI Jakarta dan Bali, membuat Yarsi Pratama University menjadi salah satu Perguruan Tinggi dengan biaya mterjangkau di Kab. Tangerang. hal ini dilakukan untuk memfasilitasi seluruh masyarakat Kab. Tangerang pada khususnya dan seluruh masyarakat provinsi Banten pada umumnya.
            </p>
            <p>Universitas Yarsi Pratama mengusung Program Studi kesehatan dan non kesehatan dimana program studi yang tersedia banyak dibutuhkan oleh dunia industri dan mampu meningkatkan kemampuan sumber daya manusia. khususnya di Kabupaten Tangerang.
            </p>
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
